@@ -2,6 +2,7 @@ from __future__ import unicode_literals
 
 from django.core.urlresolvers import reverse_lazy
 from django.views import generic
+from django.views.generic.list import MultipleObjectMixin
 
 from braces.views import StaffuserRequiredMixin
 
@@ -11,22 +12,27 @@ from .models import Category
 
 
 class CategoryDetailView(views.AddSearchFormToContextMixin,
+                         MultipleObjectMixin,
                          generic.DetailView):
 
     model = Category
+    paginate_by = 10
 
     def get_context_data(self, *args, **kwargs):
         context = super(CategoryDetailView, self).get_context_data(*args, **kwargs)
-        context['articles'] = self.object.articles.published()
         return context
 
+    @property
+    def object_list(self):
+        return self.object.articles.published()
+
 
 class CategoryCreateView(StaffuserRequiredMixin,
                          views.AuthorFormMixin,
                          generic.CreateView):
 
-    model = Category
     form_class = CategoryForm
+    model = Category
     success_url = reverse_lazy('kb:category_list')
 
 
@@ -39,8 +45,8 @@ class CategoryListView(StaffuserRequiredMixin,
 class CategoryUpdateView(StaffuserRequiredMixin,
                          generic.UpdateView):
 
-    model = Category
     form_class = CategoryForm
+    model = Category
     success_url = reverse_lazy('kb:category_list')
 
 
